@@ -6,14 +6,20 @@ from rdr import *
 
 # ngrams
 @click.command( options_metavar='<options>' )
-@click.option('-q', '--query', type=click.STRING, help="limit results to include the given word")
+@click.option('-q', '--query', type=click.STRING, help="filter results to include the given regular expression")
 @click.option('-c', '--count', is_flag=True, help='count and tabulate the result')
-@click.option('-l', '--location', default='local', type=click.Choice( [ 'local', 'remote' ] ), help='where is the library')
-@click.option('-s', '--size', default=1, help='output in a more human-readable form')
+@click.option('-l', '--location', default='local', type=click.Choice( [ 'local', 'remote' ] ), help='where is the study carrel')
+@click.option('-s', '--size', default=1, help='denote unigrams, bigrams, trigrams, etc')
 @click.argument( 'carrel', metavar='<carrel>' )
 def ngrams( carrel, size, query, count, location ) :
 
-	"""Output ngrams of the given <size> from <carrel>"""
+	"""Given <carrel>, output ngrams
+	
+	Examples:
+	
+	\b
+	  * rdr ngrams homer
+	  * rdr ngrams -l remote sonnets"""
 
 	# require
 	from re       import search
